@@ -129,6 +129,8 @@ type Config struct {
 	Edit       editCmdConfig       `mapstructure:"edit"`
 	Git        gitCmdConfig        `mapstructure:"git"`
 	Merge      mergeCmdConfig      `mapstructure:"merge"`
+	Status     statusCmdConfig     `mapstructure:"status"`
+	Verify     verifyCmdConfig     `mapstructure:"verify"`
 
 	// Command configurations, not settable in the config file.
 	apply           applyCmdConfig
@@ -145,10 +147,8 @@ type Config struct {
 	remove          removeCmdConfig
 	secret          secretCmdConfig
 	state           stateCmdConfig
-	status          statusCmdConfig
 	update          updateCmdConfig
 	upgrade         upgradeCmdConfig
-	verify          verifyCmdConfig
 
 	// Version information.
 	version     semver.Version
@@ -376,8 +376,8 @@ func newConfig(options ...configOption) (*Config, error) {
 				format: defaultWriteDataFormat,
 			},
 		},
-		status: statusCmdConfig{
-			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+		Status: statusCmdConfig{
+			Exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 			recursive: true,
 		},
@@ -391,8 +391,8 @@ func newConfig(options ...configOption) (*Config, error) {
 			owner: gitHubOwner,
 			repo:  gitHubRepo,
 		},
-		verify: verifyCmdConfig{
-			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+		Verify: verifyCmdConfig{
+			Exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll &^ chezmoi.EntryTypeScripts),
 			recursive: true,
 		},
@@ -920,7 +920,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 
 	var hostname string
 	if rawHostname, err := os.Hostname(); err == nil {
-		hostname, _, _ = chezmoi.CutString(rawHostname, "=")
+		hostname, _, _ = chezmoi.CutString(rawHostname, ".")
 	} else {
 		c.logger.Info().
 			Err(err).
